@@ -7,6 +7,10 @@ public class StringOption extends Option<String> {
 		hasArgument(true);
 	}
 
+	public StringOption(String longName) {
+		super(longName);
+		hasArgument(true);
+	}
 	public StringOption(String longName, String shortName) {
 		super(longName, shortName);
 		hasArgument(true);
