@@ -23,6 +23,7 @@ public class SectionNumberRemover implements INodeVisitor {
 		this.regex = regex;
 	}
 
+	@Override
 	public void accept(Node node) {
 
 		if (regex == null) {
@@ -80,7 +81,7 @@ public class SectionNumberRemover implements INodeVisitor {
 			title = StringServices.cutPrefix(title, sectionNumber);
 		}
 
-		return title.trim();
+		return title;
 	}
 
 	@Override
