@@ -23,6 +23,7 @@ import java.io.StringReader;
 import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.Locale;
 
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
@@ -82,6 +83,7 @@ public class DocBookTransformer {
 	private static Log logger = LogFactory.getLog(DocBookTransformer.class);
 
 	private DocBookTagFactory dbfactory;
+	private ListDetector listDetector;
 
 	/**
 	 * Einrückung für Debugging-Ausgaben
@@ -154,7 +156,7 @@ public class DocBookTransformer {
 			FileServices.createParentDir(destinationFile);
 			FileServices.writeFromString(destinationFile, buffer, script
 					.getTextParameter(DbtConstants.SECTION_DOCBOOK,
-							DbtConstants.PARAM_DOCBOOK_ENCODING, "UTF-8"));
+							DbtConstants.PARAM_ENCODING, "UTF-8"));
 			return buffer;
 
 		} catch (IOException oops) {
@@ -173,6 +175,10 @@ public class DocBookTransformer {
 
 		} catch (TrafoException oops) {
 
+			logger.fatal(
+					"Failed to convert as document. I will try to convert as fragment.",
+					oops);
+
 			Throwable cause = oops;
 
 			while (cause.getCause() != null) {
@@ -233,7 +239,7 @@ public class DocBookTransformer {
 
 			String value = script.getTextParameter(
 					DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_DOCUMENT_ELEMENT, "article");
+					DbtConstants.PARAM_DOCUMENT_ELEMENT, "article");
 
 			documentType = DocumentElementType.valueOf(value.toUpperCase());
 		}
@@ -265,7 +271,7 @@ public class DocBookTransformer {
 		}
 
 		TextParam excludeParam = (TextParam) script.getParameter(
-				DbtConstants.SECTION_HTML, DbtConstants.PARAM_HTML_EXCLUDE);
+				DbtConstants.SECTION_HTML, DbtConstants.PARAM_EXCLUDE);
 
 		if (excludeParam != null) {
 
@@ -297,7 +303,10 @@ public class DocBookTransformer {
 		pm.fireProgressEvent(new ProgressEvent("Transformation...", false));
 		pm.setProgressMaximum(nodeCounter.getNumberOfNodes());
 
+		listDetector = new ListDetector();
+
 		if (parent instanceof DocBookElement) {
+
 			root = edit(htmlRoot, (DocBookElement) parent);
 		}
 
@@ -337,17 +346,8 @@ public class DocBookTransformer {
 		new PostprocessStage3(dbfactory, postprocessStage1.getSubtables())
 				.process();
 
-		// pm.nextStage();
-		// if (scriptManager.docbookScriptsAvailable()) {
-		// pm.fireProgressEvent(new ProgressEvent(
-		// "Customizing DocBook tree...", false));
-		// root.traverse(nodeCounter.reset());
-		// pm.setProgressMaximum(nodeCounter.getNumberOfNodes());
-		// customizeDocBook((Element) root);
-		// }
-
 		boolean addIndex = script.isParameterOn(DbtConstants.SECTION_DOCBOOK,
-				DbtConstants.PARAM_DOCBOOK_ADD_INDEX, false);
+				DbtConstants.PARAM_ADD_INDEX, false);
 
 		if (addIndex == true) {
 			root.appendChild(dbfactory.createIndex());
@@ -385,8 +385,7 @@ public class DocBookTransformer {
 			logger.debug("Transformer out=" + xml);
 
 			String destinationEncoding = script.getTextParameter(
-					DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_ENCODING,
+					DbtConstants.SECTION_DOCBOOK, DbtConstants.PARAM_ENCODING,
 					DbtConstants.DEFAULT_DESTINATION_ENCODING);
 			byte[] data = XmlServices.validate(xml, destinationEncoding);
 			result.setData(data);
@@ -456,8 +455,6 @@ public class DocBookTransformer {
 			DocumentElementType documentType, TrafoResult result)
 			throws TrafoException {
 
-		logger.debug("-> transformDocument");
-
 		if (script == null) {
 			script = new Script();
 		}
@@ -474,6 +471,12 @@ public class DocBookTransformer {
 			}
 
 			HtmlDocument htmlDoc = parser.parseDocument(htmlCode);
+
+			if (logger.isTraceEnabled()) {
+				NodeSerializer serializer = new NodeSerializer();
+				serializer.write(htmlDoc, new File("__trace__herold.html"));
+			}
+
 			HtmlElement documentElement = htmlDoc.getDocumentElement();
 
 			String lang = null;
@@ -485,19 +488,28 @@ public class DocBookTransformer {
 			documentElement.removeAttribute("xmlns");
 
 			String language = script.getTextParameter(
-					DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_LANGUAGE, null);
+					DbtConstants.SECTION_DOCBOOK, DbtConstants.PARAM_LANGUAGE,
+					null);
+
+			logger.debug("Profile: Parameter language = " + language);
 
 			if (language == null) {
+
 				lang = detectLanguage(documentElement);
+				logger.debug("Detected language from HTML = " + lang);
+
+				if (lang == null) {
+					lang = Locale.getDefault().getLanguage().toLowerCase();
+					logger.debug("Using default language from JVM = " + lang);
+				}
+
 			} else {
 				lang = language;
 			}
 
 			DocBookDocument doc = new DocBookDocument();
 			doc.setXmlEncoding(script.getTextParameter(
-					DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_ENCODING,
+					DbtConstants.SECTION_DOCBOOK, DbtConstants.PARAM_ENCODING,
 					DbtConstants.DEFAULT_DESTINATION_ENCODING));
 
 			DocBookTagFactory dbf = getTagFactory();
@@ -522,6 +534,7 @@ public class DocBookTransformer {
 			}
 
 			if (lang != null) {
+				logger.debug("Setting attribute xml:lang to " + lang);
 				rootElement.setAttributeNS(
 						"http://www.w3.org/XML/1998/namespace", "xml:lang",
 						lang);
@@ -531,8 +544,8 @@ public class DocBookTransformer {
 			rootElement.appendChild(info);
 
 			String title = script.getTextParameter(
-					DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_TITLE, null);
+					DbtConstants.SECTION_DOCBOOK, DbtConstants.PARAM_TITLE,
+					null);
 
 			if (title != null && title.trim().length() > 0) {
 				info.appendChild(dbf.createTitle(title));
@@ -541,8 +554,8 @@ public class DocBookTransformer {
 			}
 
 			String abstractText = script.getTextParameter(
-					DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_ABSTRACT, null);
+					DbtConstants.SECTION_DOCBOOK, DbtConstants.PARAM_ABSTRACT,
+					null);
 
 			if (abstractText != null) {
 				Abstract abstractElement = dbf.createAbstract();
@@ -609,6 +622,7 @@ public class DocBookTransformer {
 
 	private void generateTitle(HtmlDocument htmlDoc, DocBookTagFactory dbf,
 			Info info) {
+
 		HtmlElement elem = (HtmlElement) XPathServices.getNode(htmlDoc,
 				"/html/head/title");
 
@@ -653,7 +667,7 @@ public class DocBookTransformer {
 		}
 
 		script.setEnabled(DbtConstants.SECTION_DOCBOOK,
-				DbtConstants.PARAM_DOCBOOK_ADD_INDEX, false);
+				DbtConstants.PARAM_ADD_INDEX, false);
 
 		try {
 
@@ -675,11 +689,9 @@ public class DocBookTransformer {
 			StringWriter buffer = serialize(elem);
 
 			logger.debug("<- transformFragment");
-
 			return buffer.toString();
 
 		} catch (Exception oops) {
-
 			throw new TrafoException(oops);
 		}
 
@@ -956,8 +968,10 @@ public class DocBookTransformer {
 
 					} else {
 
-						values = editor.edit(values);
-
+						if (beforeEdit(values)) {
+							values = editor.edit(values);
+							afterEdit(values);
+						}
 					}
 
 					dbElement = values.getCurrent();
@@ -1048,6 +1062,23 @@ public class DocBookTransformer {
 		return dbParent;
 	}
 
+	private void afterEdit(EditorInstruction values) {
+	}
+
+	private boolean beforeEdit(EditorInstruction values) {
+
+		listDetector.edit(values);
+
+		SectionDetector sectionDetector = new SectionDetector();
+		HtmlElement htmlElement = values.getHtmlElement();
+		if (sectionDetector.isSection(htmlElement, getScript())) {
+			sectionDetector.edit(values);
+			return false;
+		}
+
+		return true;
+	}
+
 	private boolean isInstruction(CommentImpl comment) {
 
 		if (comment == null) {
@@ -1120,7 +1151,7 @@ public class DocBookTransformer {
 			String docBookCode = convert(buffer.toString());
 
 			encoding = script.getTextParameter(DbtConstants.SECTION_DOCBOOK,
-					DbtConstants.PARAM_DOCBOOK_ENCODING, "UTF-8");
+					DbtConstants.PARAM_ENCODING, "UTF-8");
 
 			PrintWriter writer = new PrintWriter(new OutputStreamWriter(out,
 					encoding));
