@@ -8,5 +8,5 @@
  */
 package org.dbdoclet.trafo.html.docbook.editor;
 
-public class H2Editor extends HeaderBaseEditor {
+public class H2Editor extends HeadingEditor {
 }
