@@ -9,6 +9,6 @@
 package org.dbdoclet.trafo.html.docbook.editor;
 
 
-public class H4Editor extends HeaderBaseEditor {
+public class H4Editor extends HeadingEditor {
 
     }
