@@ -8,6 +8,8 @@
  */
 package org.dbdoclet.trafo.html.docbook.editor;
 
+import org.dbdoclet.trafo.html.docbook.DbtConstants;
+import org.dbdoclet.trafo.script.Script;
 import org.dbdoclet.trafo.tag.docbook.DocBookElement;
 import org.dbdoclet.trafo.tag.docbook.DocBookTagFactory;
 import org.dbdoclet.trafo.tag.docbook.Para;
@@ -26,6 +28,7 @@ public class TextEditor extends Editor {
 
 			DocBookElement parent = getParent();
 			DocBookElement current = getCurrent();
+			Script script = getTransformer().getScript();
 
 			if (parent.isContentModel()) {
 
@@ -43,9 +46,15 @@ public class TextEditor extends Editor {
 			}
 
 			String text = getCharacterDataNode().getData();
+
+			if (script.isParameterOn(DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_COLLAPSE_PROTECTED_SPACE, false)) {
+				text = text.replace('\u00a0', ' ');
+			}
+
 			current.appendChild(text);
 			return finalizeValues();
-			
+
 		} catch (Exception oops) {
 
 			throw new EditorException(oops);
