@@ -24,7 +24,7 @@ public class TheadEditor extends Editor {
 		Script script = getTransformer().getScript();
 		boolean decomposeTables = script.isParameterOn(
 				DbtConstants.SECTION_DOCBOOK,
-				DbtConstants.PARAM_DOCBOOK_DECOMPOSE_TABLES,
+				DbtConstants.PARAM_DECOMPOSE_TABLES,
 				DbtConstants.DEFAULT_DECOMPOSE_TABLES);
 
 		if (decomposeTables) {
