@@ -154,7 +154,7 @@ public class HtmlParser {
 
 		NodeListImpl childNodes = node.getTrafoChildNodes();
 
-		for (NodeImpl child : childNodes) {
+		for (NodeImpl child : new ArrayList<NodeImpl>(childNodes)) {
 
 			NodeImpl parent = child.getTrafoParentNode();
 
