@@ -1,20 +1,10 @@
-/* 
- * Copyright (C) 2001-2012 Michael Fuchs
+/*
+ * ### Copyright (C) 2008 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@dbdoclet.org
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.trafo.tag.docbook;
 
@@ -569,14 +559,12 @@ public class DocBookTagFactory {
 	}
 
 	public Keyword createKeyword() {
-
 		Keyword keyword = new Keyword();
 		keyword.setDocBookVersion(docBookVersion);
 		return keyword;
 	}
 
 	public Keywordset createKeywordset() {
-
 		Keywordset keywordset = new Keywordset();
 		keywordset.setDocBookVersion(docBookVersion);
 		return keywordset;
@@ -1125,8 +1113,25 @@ public class DocBookTagFactory {
 		return spanspec;
 	}
 
-	public Subscript createSubscript() {
+	public Subject createSubject() {
+		Subject subject = new Subject();
+		subject.setDocBookVersion(docBookVersion);
+		return subject;
+	}
 
+	public Subjectset createSubjectset() {
+		Subjectset subjectset = new Subjectset();
+		subjectset.setDocBookVersion(docBookVersion);
+		return subjectset;
+	}
+
+	public Subjectterm createSubjectterm() {
+		Subjectterm subjectterm = new Subjectterm();
+		subjectterm.setDocBookVersion(docBookVersion);
+		return subjectterm;
+	}
+
+	public Subscript createSubscript() {
 		Subscript subscript = new Subscript();
 		subscript.setDocBookVersion(docBookVersion);
 		return subscript;
