@@ -8,6 +8,8 @@ import java.io.StringWriter;
 import java.io.Writer;
 import java.util.ArrayList;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.dbdoclet.Sfv;
 import org.dbdoclet.progress.ProgressEvent;
 import org.dbdoclet.progress.ProgressListener;
@@ -29,6 +31,8 @@ import org.w3c.dom.Text;
 
 public class NodeSerializer {
 
+	private static Log logger = LogFactory.getLog(NodeSerializer.class);
+
 	private ArrayList<ProgressListener> listeners;
 	private int literalContext = 0;
 
@@ -213,7 +217,14 @@ public class NodeSerializer {
 			break;
 
 		case Node.ELEMENT_NODE:
-			writeElement(node, out, inMixedContent, indent);
+
+			try {
+				writeElement(node, out, inMixedContent, indent);
+			} catch (StackOverflowError oops) {
+				logger.fatal("[NodeSerializer.write] StackOverflowError. Possibly recursive structure detected!!! Node: "
+						+ node.toString());
+			}
+
 			break;
 
 		case Node.TEXT_NODE:
