@@ -345,19 +345,30 @@ public class XmlServices {
 					"The argument source must not be null!");
 		}
 
-		BufferedReader reader = new BufferedReader(new FileReader(source));
-		String line;
+		BufferedReader reader = null;
 
-		Matcher matcher;
+		try {
 
-		while ((line = reader.readLine()) != null) {
+			reader = new BufferedReader(new FileReader(source));
+			String line;
 
-			logger.debug("line=" + line);
+			Matcher matcher;
 
-			matcher = encPattern.matcher(line);
+			while ((line = reader.readLine()) != null) {
 
-			if (matcher.matches()) {
-				return matcher.group(1);
+				logger.debug("line=" + line);
+
+				matcher = encPattern.matcher(line);
+
+				if (matcher.matches()) {
+					return matcher.group(1);
+				}
+			}
+
+		} finally {
+
+			if (reader != null) {
+				reader.close();
 			}
 		}
 
@@ -681,6 +692,7 @@ public class XmlServices {
 		factory.setValidating(false);
 		DocumentBuilder parser = factory.newDocumentBuilder();
 		parser.setEntityResolver(new EntityResolver() {
+			@Override
 			public InputSource resolveEntity(String publicId, String systemId)
 					throws SAXException, IOException {
 				return new InputSource(new ByteArrayInputStream(
@@ -726,8 +738,8 @@ public class XmlServices {
 		}
 
 		Document doc = parse(file, false, schemaUrl);
-        NodeSerializer serializer = new NodeSerializer();
-        serializer.write(doc, file, to);
+		NodeSerializer serializer = new NodeSerializer();
+		serializer.write(doc, file, to);
 	}
 
 	public static String replaceAmpersand(String text, boolean isHtml) {
@@ -1445,7 +1457,8 @@ public class XmlServices {
 		text = StringServices.replace(text, "<", "&lt;");
 		text = StringServices.replace(text, ">", "&gt;");
 		text = StringServices.replace(text, "\"", "&quot;");
-		text = StringServices.replace(text, "\uF0E0", "<img class=\"arrowImage\" src=\"../../../img/uF0E0.png\">");
+		text = StringServices.replace(text, "\uF0E0",
+				"<img class=\"arrowImage\" src=\"../../../img/uF0E0.png\">");
 
 		if (isHtml == true) {
 			text = StringServices.replace(text, "'", "&#39;");
@@ -1960,6 +1973,27 @@ public class XmlServices {
 		}
 
 		NodeSerializer serializer = new NodeSerializer();
-        serializer.write(doc, file);
+		serializer.write(doc, file);
+	}
+
+	public static String printPath(Node node) {
+
+		if (node == null) {
+			return "Path: null";
+		}
+
+		StringBuilder buffer = new StringBuilder();
+
+		Node parent = node;
+
+		while (parent != null) {
+			buffer.insert(0, " -> ");
+			buffer.insert(0, parent.getNodeName());
+			parent = parent.getParentNode();
+		}
+
+		String text = buffer.toString();
+		text = StringServices.cutPrefix(text, " -> ");
+		return "Path: " + text;
 	}
 }
