@@ -30,7 +30,7 @@ public class ElementByTagNameVisitor implements INodeVisitor {
     
         if (tagName != null && otherTagName != null) {
             if (tagName.equals(otherTagName)) {
-                elementList.add((ElementImpl) element);
+                elementList.add((NodeImpl) element);
             }
         }
     }
