@@ -1,20 +1,12 @@
 /* 
- * Copyright (C) 2001-2012 Michael Fuchs
+ * $Id$
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * ### Copyright (C) 2006 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
+ *
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@unico-group.com
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.xiphias.dom;
 
@@ -455,14 +447,15 @@ public class ElementImpl extends NodeImpl implements Element {
 	 * @param type
 	 * @return ArrayList<ElementImpl>
 	 */
-	public ArrayList<Element> findChildren(Class<? extends ElementImpl> type) {
+	@SuppressWarnings("unchecked")
+	public <T extends Element> ArrayList<T> findChildren(Class<T> type) {
 
-		ArrayList<Element> list = new ArrayList<Element>();
+		ArrayList<T> list = new ArrayList<T>();
 
 		for (Element element : getChildElementList()) {
 
 			if (type.isInstance(element)) {
-				list.add(element);
+				list.add((T) element);
 			}
 		}
 
