@@ -23,6 +23,7 @@ import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
+import org.w3c.dom.Text;
 import org.w3c.dom.UserDataHandler;
 
 /**
@@ -46,45 +47,6 @@ public class NodeImpl implements Node {
 	private static Log logger = LogFactory.getLog(NodeImpl.class);
 	private static final String LSEP = System.getProperty("line.separator");
 
-	private NodeListImpl childNodes = new NodeListImpl();
-	private DocumentImpl document;
-	private boolean isEmpty = false;
-	private boolean isMute = false;
-	private boolean isRawData = false;
-	private String namespaceUri;
-	private boolean needsPadding = false;
-	private String nodeName = "node";
-	private short nodeType = ELEMENT_NODE;
-	private String nodeValue;
-	private NodeImpl parent = null;
-	private TransformInstruction transformInstruction;
-	private HashMap<String, Object> userDataMap;
-	private int column;
-	private int line;
-
-	protected boolean isCaseInsensitive = false;
-
-	public NodeImpl() {
-		super();
-	}
-
-	public NodeImpl(String name) {
-		this(name, null);
-	}
-
-	public NodeImpl(String name, NodeImpl parent) {
-
-		if (name != null) {
-			nodeName = name;
-		}
-
-		if (isCaseInsensitive) {
-			nodeName = nodeName.toLowerCase();
-		}
-
-		this.parent = parent;
-	}
-
 	/**
 	 * The method <code>findParent</code> tries to find the nearest parent,
 	 * which is of type <code>parentClass</code>.
@@ -104,9 +66,7 @@ public class NodeImpl implements Node {
 		}
 
 		Node parent = node.getParentNode();
-
 		while (parent != null && !parentClass.isInstance(parent)) {
-
 			parent = parent.getParentNode();
 		}
 
@@ -144,7 +104,12 @@ public class NodeImpl implements Node {
 
 			} else {
 
-				buffer += NodeImpl.getTextContent(o);
+				try {
+					buffer += NodeImpl.getTextContent(o);
+				} catch (StackOverflowError oops) {
+					logger.fatal("[NodeImpl.getTextContent] StackOverflowError. Possibly recursive structure detected!!! Node: "
+							+ node.toString());
+				}
 			}
 		}
 
@@ -157,17 +122,14 @@ public class NodeImpl implements Node {
 
 		case HTML:
 			flavour = HTML;
-
 			break;
 
 		case SGML:
 			flavour = SGML;
-
 			break;
 
 		case XML:
 			flavour = XML;
-
 			break;
 
 		default:
@@ -214,6 +176,50 @@ public class NodeImpl implements Node {
 		}
 	}
 
+	private NodeListImpl childNodes = new NodeListImpl();
+	private DocumentImpl document;
+	private boolean isEmpty = false;
+	private boolean isMute = false;
+	private boolean isRawData = false;
+	private String namespaceUri;
+	private boolean needsPadding = false;
+	private String nodeName = "node";
+	private short nodeType = ELEMENT_NODE;
+	private String nodeValue;
+
+	private NodeImpl parent = null;
+
+	private TransformInstruction transformInstruction;
+
+	private HashMap<String, Object> userDataMap;
+
+	private int column;
+
+	private int line;
+
+	protected boolean isCaseInsensitive = false;
+
+	public NodeImpl() {
+		super();
+	}
+
+	public NodeImpl(String name) {
+		this(name, null);
+	}
+
+	public NodeImpl(String name, NodeImpl parent) {
+
+		if (name != null) {
+			nodeName = name;
+		}
+
+		if (isCaseInsensitive) {
+			nodeName = nodeName.toLowerCase();
+		}
+
+		this.parent = parent;
+	}
+
 	@Override
 	public Node appendChild(Node newChild) throws DOMException {
 
@@ -289,6 +295,23 @@ public class NodeImpl implements Node {
 		return 0;
 	}
 
+	public Text findFirstText() {
+
+		Text firstText = getFirstText();
+		if (firstText != null) {
+			return firstText;
+		}
+
+		for (Element element : getChildElementList()) {
+			firstText = ((ElementImpl) element).findFirstText();
+			if (firstText != null) {
+				return firstText;
+			}
+		}
+
+		return null;
+	}
+
 	public NodeImpl findChildElement(String tagName) {
 
 		if (tagName == null) {
@@ -453,6 +476,25 @@ public class NodeImpl implements Node {
 		return (Element) element;
 	}
 
+	public Text getFirstText() {
+
+		if ((childNodes == null) || (childNodes.size() < 1)) {
+			return null;
+		}
+
+		NodeImpl element = null;
+
+		for (int i = 0; i < childNodes.size(); i++) {
+
+			if (childNodes.get(i) instanceof Text) {
+				element = childNodes.get(i);
+				break;
+			}
+		}
+
+		return (Text) element;
+	}
+
 	/* ========================================================== */
 	/* Extensions */
 	/* ========================================================== */
@@ -794,7 +836,7 @@ public class NodeImpl implements Node {
 		return false;
 	}
 
-	public NodeImpl insertAfter(Node newChild, Node refChild) {
+	public Node insertAfter(Node newChild, Node refChild) {
 
 		if (newChild == null) {
 			throw new IllegalArgumentException(
@@ -872,6 +914,29 @@ public class NodeImpl implements Node {
 		return this;
 	}
 
+	/**
+	 * Falls die Sprache nicht zwischen Groß- und Kleinschreibung unterscheidet,
+	 * muss das Attribute <code>isCaseSensitive</code> auf <code>true</code>
+	 * gesetzt werden.
+	 * 
+	 * <p>
+	 * Die Methode konvertiert bereits bestehende Daten in Kleinbuchstaben.
+	 * Sollten dabei Doppeldeutigkeiten auftreten, gilt der letzte, verarbeitete
+	 * Wert.
+	 * 
+	 * @param isCaseInsensitive
+	 * @return NodeImpl
+	 */
+	public NodeImpl isCaseInsensitive(boolean isCaseInsensitive) {
+		this.isCaseInsensitive = isCaseInsensitive;
+
+		if (nodeName != null) {
+			nodeName = nodeName.toLowerCase();
+		}
+
+		return this;
+	}
+
 	@Override
 	public boolean isDefaultNamespace(String namespaceURI) {
 		System.err.println("Not yet implemented");
@@ -1160,18 +1225,23 @@ public class NodeImpl implements Node {
 
 		StringBuilder buffer = new StringBuilder();
 
+		buffer.append("name=");
 		if (nodeName != null) {
-			buffer.append("name=");
 			buffer.append(nodeName);
-			buffer.append(' ');
 		}
 
+		buffer.append(',');
+		buffer.append("value=");
 		if (nodeValue != null) {
-			buffer.append("value=");
 			buffer.append(nodeValue);
-			buffer.append(' ');
 		}
 
+		buffer.append(",line=");
+		buffer.append(getLine());
+
+		buffer.append(",column=");
+		buffer.append(getColumn());
+
 		String text = buffer.toString();
 
 		if (text.length() > 42) {
@@ -1258,6 +1328,12 @@ public class NodeImpl implements Node {
 		return toTree("", levels, 0);
 	}
 
+	protected boolean validateAttributes() {
+
+		// To be overwritten
+		return true;
+	}
+
 	public boolean validateParentPath(
 			HashMap<String, HashMap<String, String>> validParentMap) {
 
@@ -1314,33 +1390,4 @@ public class NodeImpl implements Node {
 		}
 	}
 
-	protected boolean validateAttributes() {
-
-		// To be overwritten
-		return true;
-	}
-
-	/**
-	 * Falls die Sprache nicht zwischen Groß- und Kleinschreibung unterscheidet,
-	 * muss das Attribute <code>isCaseSensitive</code> auf <code>true</code>
-	 * gesetzt werden.
-	 * 
-	 * <p>
-	 * Die Methode konvertiert bereits bestehende Daten in Kleinbuchstaben.
-	 * Sollten dabei Doppeldeutigkeiten auftreten, gilt der letzte, verarbeitete
-	 * Wert.
-	 * 
-	 * @param isCaseInsensitive
-	 * @return NodeImpl
-	 */
-	public NodeImpl isCaseInsensitive(boolean isCaseInsensitive) {
-		this.isCaseInsensitive = isCaseInsensitive;
-
-		if (nodeName != null) {
-			nodeName = nodeName.toLowerCase();
-		}
-
-		return this;
-	}
-
 }
